@@ -1100,5 +1100,5 @@ class App(object):
                         check_name, lib=f.read()
                     )
         except Exception:
-            logger.error("read file % failed", filepath)
+            logger.error("read file %s failed", filepath)
         return False
