@@ -319,6 +319,44 @@ def check_for_valid_ui_label(app, reporter):
         return
 
 
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+def check_reload_trigger_for_all_custom_confs(app, reporter):
+    """Check that custom conf files have a corresponding reload trigger in app.conf
+
+    Without a reload trigger the app will request a restart on any change to the conf file,
+    which may be a negative experience for end-users.
+    """
+
+    # Get all custom confs
+    custom_confs = []
+    for directory, filename, _ in app.iterate_files(
+            types=[".conf"], basedir=["default", "local"]
+    ):
+        if filename not in SPLUNK_DEFINED_CONFS:
+            custom_confs.append(filename)
+
+    # Pass the check if there are no custom confs
+    if not custom_confs:
+        return
+
+    # Get the app config
+    app_conf = app.app_conf()
+    if not app_conf.has_section("triggers"):
+        reporter.warn(f"App contains custom conf(s) {custom_confs} but does not have a [triggers] stanza in app.conf. "
+                      f"Without a reload trigger the app will request a restart on any change to the conf file, "
+                      f"which may be a negative experience for end-users.")
+        return
+
+    # Check that all the custom confs have a reload trigger
+    # e.g. "banana.conf" -> "reload.banana" in app.conf
+    for custom_conf in custom_confs:
+        reload_option_name = f"reload.{os.path.splitext(custom_conf)[0]}"
+        if not app_conf.has_option("triggers", reload_option_name):
+            reporter.warn(f"Custom conf file {custom_conf} does not have a reload trigger in app.conf. "
+                          f"Without a reload trigger the app will request a restart on any change to the conf file, "
+                          f"which may be a negative experience for end-users.")
+
+
 def _get_conf_permissions(default_meta):
     conf_permissions = {}
     meta_stanza_pattern = r"(?=\/).*"
