@@ -55,7 +55,7 @@ def check_lookup_csv_is_valid(app, reporter):
             )
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.0")
 def check_for_lookups_file_name(app, reporter):
     """Check that no two files/directories under the lookups directory have this naming pattern respectively: 
