@@ -21,7 +21,7 @@ logger = logging.getLogger(__name__)
 report_display_order = 7
 
 
-@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_that_all_xml_files_are_well_formed(app, reporter):
     """Check that all XML files are well-formed."""
@@ -38,7 +38,7 @@ def check_that_all_xml_files_are_well_formed(app, reporter):
     for relative_filepath, full_filepath in app.get_filepaths_of_files(types=[".xml"]):
         try:
             parse_xml(full_filepath)
-        except xml.sax.SAXException:
+        except (xml.sax.SAXException, ValueError):
             reporter.fail(
                 "Invalid XML file: {}".format(relative_filepath), relative_filepath
             )
