@@ -1,6 +1,7 @@
 """Splunk cron expression abstraction module"""
 
 from builtins import range
+from croniter import croniter
 
 
 class CronExpression(object):
@@ -8,7 +9,7 @@ class CronExpression(object):
 
     def __init__(self, cron_expression):
         self.expression = cron_expression
-        self._is_valid = True
+        self._is_valid = croniter.is_valid(cron_expression)
         self.fields = self.expression.split()
         if len(self.fields) != 5:
             self._is_valid = False
