@@ -1,7 +1,13 @@
+"""
+Datetime formatter for AppInspect report formatter
+"""
+
 # Python Standard Libraries
 import json
+
 # Third-Party Libraries
 import datetime
+
 # Custom Libraries
 # N/A
 
@@ -9,7 +15,7 @@ import datetime
 class DateTimeEncoder(json.JSONEncoder):
     """A custom JSON encoder created to fix serialization issues."""
 
-    def default(self, obj): # pylint: disable=method-hidden
+    def default(self, obj):  # pylint: disable=E0202,W0221
         if isinstance(obj, datetime.datetime):
             return obj.isoformat()
 
